@@ -4,6 +4,8 @@ from urllib.parse import ParseResult, urljoin, urlparse, uses_query
 
 from typing import BinaryIO, Callable, Dict, List, Optional, Type, TypeVar, Union
 
+from storage.url_parser import sanitize_resource_uri
+
 
 _STORAGE_TYPES = {}         # maintains supported storage protocols
 _LARGE_CHUNK = 32 * 1024 * 1024
@@ -39,6 +41,10 @@ def register_storage_protocol(scheme: str) -> Callable[[Type["Storage"]], Type["
     return decorate_storage_protocol
 
 
+class NotFoundError(Exception):
+    pass
+
+
 class DownloadUrlBaseUndefinedError(Exception):
     """Exception raised when a download url has been requested and
     no download_url_base has been defined for the storage object.
@@ -129,6 +135,9 @@ class Storage(object):
         raise NotImplementedError(
             "{} does not implement 'get_download_url'".format(self._class_name()))
 
+    def get_sanitized_uri(self) -> str:
+        return sanitize_resource_uri(self._parsed_storage_uri)
+
 
 def _generate_download_url_from_base(base: Union[str, None], object_name: str) -> str:
     """Generate a download url by joining the base with the storage object_name.
@@ -147,8 +156,11 @@ class InvalidStorageUri(RuntimeError):
 
 
 def get_storage(storage_uri: str) -> Storage:
-    storage_type = storage_uri.split("://")[0]
-    return _STORAGE_TYPES[storage_type](storage_uri)
+    storage_type = urlparse(storage_uri).scheme
+    try:
+        return _STORAGE_TYPES[storage_type](storage_uri)
+    except KeyError:
+        raise InvalidStorageUri(f"Invalid storage type '{storage_type}'")
 
 
 ParsedQuery = Dict[str, List[str]]
